==> haskell-criterion-measurement-0.1.1.0-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion-measurement
version: 0.1.1.0
id: criterion-measurement-0.1.1.0-OK5dvDsLPDBJb6dZCkU4A
key: criterion-measurement-0.1.1.0-OK5dvDsLPDBJb6dZCkU4A
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/criterion
synopsis: Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.
category: Development, Performance, Testing, Benchmarking
abi: 17c1cad5317ac1d18a66505068b7227a
exposed: True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-measurement-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-measurement-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/criterion-measurement-0.1.1.0
hs-libraries: HScriterion-measurement-0.1.1.0-OK5dvDsLPDBJb6dZCkU4A
depends:
    aeson-1.4.3.0-5u6hknCeN6OEP5DlN5W0LL base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr binary-0.8.6.0
    containers-0.6.0.1 deepseq-1.4.4.0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock
haddock-html: /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.1.1.0-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion-measurement
version: 0.1.1.0
id: criterion-measurement-0.1.1.0-F5T7zTqoH4e6czv6hszZyv
key: criterion-measurement-0.1.1.0-F5T7zTqoH4e6czv6hszZyv
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/criterion
synopsis: Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.
category: Development, Performance, Testing, Benchmarking
abi: 9c780147ce3df3166472e8938a010678
exposed: True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-measurement-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-measurement-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/criterion-measurement-0.1.1.0
hs-libraries: HScriterion-measurement-0.1.1.0-F5T7zTqoH4e6czv6hszZyv
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr binary-0.8.6.0
    containers-0.6.0.1 deepseq-1.4.4.0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock
haddock-html: /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
